<?php

include_once 'config.php';

// DBアクセスクラス
class DbAccess
{

    private $con_str = "";

    /*
      コンストラクタ
      大域変数_DB_CONFIGを取得し、DB接続情報文字列を生成
    */
    public function __construct()
    {
        $db_config = $GLOBALS['_DB_CONFIG'];
        $this->con_str = "dbname=" . $db_config['dbname'] . " host=" . $db_config['host'] . " user=" . $db_config['user'];
        if ($db_config['password']) {
            $this->con_str = $this->con_str . " password=" . $db_config['password'];
        }
    }

    /*
      すべての仕入れ情報を取得
    */
    public function getAllOrders()
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // SQLを実行
        $sql = "SELECT * FROM orders";
        $result = pg_query($dbcon, $sql);
        pg_close($dbcon);

        if (pg_num_rows($result) < 1) {
            return NULL;
        }

        return $result;
    }

    /*
       すべての商品情報を所得
    */
    public function getAllProducts()
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // SQLを実行
        $q = "SELECT name FROM products";
        $result = pg_query($dbcon, $q);
        pg_close($dbcon);

        if (pg_num_rows($result) < 1) {
            return NULL;
        }

        return $result;
    }

    /*
       すべての仕入れ先情報を所得
    */
    public function getAllSuppliers()
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // SQLを実行
        $q = "SELECT farm_name FROM supplier";
        $result = pg_query($dbcon, $q);
        pg_close($dbcon);

        if (pg_num_rows($result) < 1) {
            return NULL;
        }

        return $result;
     }

     /*
      * 仕入れ情報を登録する
      */
     public function addOrder($name, $farm_name, $arrival_date, $order_num)
     {

         // DB接続
         $dbcon = pg_connect($this->con_str);

         // DB接続失敗時の処理
         if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
         }

         // SQLを実行
         $q = "INSERT INTO orders (name, farm_name, arrival_date, order_num) VALUES ('" . $name . "','" . $farm_name . "','" . $arrival_date . "'," . $order_num . ")";
         $result = pg_query($dbcon, $q);
         pg_close($dbcon);

         return true;
    }

    /*
     * 仕入れ情報取得
     * 指定されたorder_noの仕入れ情報を取得
     */
    public function getOrder($order_no)
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // SQLを実行
        $q = "SELECT * FROM orders WHERE order_no = " . $order_no . " limit 1";
        $result = pg_query($dbcon, $q);
        pg_close($dbcon);

        if (pg_num_rows($result) != 1) {
            return NULL;
        }

        // 結果の返却
        return $result;
    }

    /*
     * 仕入れ情報更新
     * 指定されたorder_noの仕入れ情報を更新
     */
    public function updateOrder($order_no, $name, $farm_name, $arrival_date, $order_num, $order_no)
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // SQLを実行
        $q = "UPDATE orders SET "
                . "name = '$name',"
                . "farm_name = '$farm_name'," 
                . "arrival_date = '$arrival_date'," 
                . "order_num = $order_num " 
                . " WHERE order_no = $order_no";
        $result = pg_query($dbcon, $q);
        pg_close($dbcon);

        return $result;

    }

    /*
     * 仕入れ情報削除
     * 指定されたorder_noの仕入れ情報を削除
     */
    public function deleteOrder($order_no)
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // SQLを実行
        $q = "DELETE FROM orders WHERE order_no = " . $order_no;
        $result = pg_query($dbcon, $q);
        pg_close($dbcon);

        return $result;
    }

    /*
     * 仕入れ情報削除
     */
    public function searchOrder($name, $farm_name, $from_arrival_date, $to_arrival_date, $from_order_num, $to_order_num)
    {
        // DB接続
        $dbcon = pg_connect($this->con_str);

        // DB接続失敗時の処理
        if (!$dbcon) {
            pg_close($dbcon);
            return NULL;
        }

        // WHERE句の作成
        $where = "";
        if ($name != null && $name != "") {
            $where = " WHERE name = '" . $name . "'";
        }
        if ($farm_name != null && $farm_name != "") {
            if ($where != "") {
                $where .= " AND farm_name = '" . $farm_name . "'";
            } else {
                $where = " WHERE farm_name = '" . $farm_name . "'";
            }
        }
        if ($from_arrival_date != null && $from_arrival_date != "") {
            if ($where != "") {
                $where .= " AND arrival_date >= '" . $from_arrival_date . "'";
            } else {
                $where = " WHERE arrival_date >= '" . $from_arrival_date . "'";
            }
        }
        if ($to_arrival_date != null && $to_arrival_date != "") {
            if ($where != "") {
                $where .= " AND arrival_date <= '" . $to_arrival_date . "'";
            } else {
                $where = " WHERE arrival_date <= '" . $to_arrival_date . "'";
            }
        }
        if ($from_order_num != null && $from_order_num != "") {
            if ($where != "") {
                $where .= " AND order_num >= '" . $from_order_num . "'";
            } else {
                $where = " WHERE order_num >= '" . $from_order_num . "'";
            }
        }
        if ($to_order_num != null && $to_order_num != "") {
            if ($where != "") {
                $where .= " AND order_num <= " . $to_order_num;
            } else {
                $where = " WHERE order_num <= " . $to_order_num;
            }
        }

        // SQLを実行
        $q = "SELECT * FROM orders" . $where;
        $result = pg_query($dbcon, $q);
        pg_close($dbcon);

        if (pg_num_rows($result) < 1) {
            return NULL;
        }

        return $result;
    }

}

?>
